/******************************************************************************/
/* TEKNISA                                                                    */
/******************************************************************************/
/*                                                                            */
/* NOME: GRAVA_MOVOPSOL                                                       */
/*                                                                            */
/* DESCRIO:                                                                 */
/*   Grava log de ITEMSOLI                                                 */
/*                                                                            */
/* CRIAO:                                                                   */
/* 12/02/2004 - Luiz Otvio de Souza                                          */
/*                                                                            */
/******************************************************************************/


IF EXISTS(SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'GRAVA_MOVOPSOL'  and
            type = 'TR'                 and
            u.uid = o.uid               and
            u.name = USER)
  DROP TRIGGER GRAVA_MOVOPSOL
  GO

CREATE TRIGGER GRAVA_MOVOPSOL
ON ITEMSOLI
FOR INSERT, UPDATE, DELETE

AS

DECLARE @V_IDGRAVLOGSOL VARCHAR(03);
DECLARE @V_DSRDMUSUMOVS VARCHAR(50);
DECLARE @V_DSENDUSUMOVS VARCHAR(50);
DECLARE @V_DSNMUSUMOVS  VARCHAR(50);
DECLARE @V_DSMETUSUMOVS VARCHAR(250);

/* Declarao de Variveis */
DECLARE @V_IDCOMANDO      VARCHAR(1);
DECLARE @V_CDFILSOLI      VARCHAR(4);
DECLARE @V_CDFILLAN       VARCHAR(4);
DECLARE @V_NRSOLICMP      VARCHAR(10);
DECLARE @V_CDPRODUTO      VARCHAR(10);
DECLARE @V_DTPROGENTR     DATETIME;
DECLARE @V_OLD_QTSOLIPROD DOUBLE PRECISION;
DECLARE @V_NEW_QTSOLIPROD DOUBLE PRECISION;

BEGIN
   DECLARE C_DADOS CURSOR FOR
     SELECT
       'D' IDCOMANDO,
       CDFILSOLI,
       CDFILLAN,
       NRSOLICMP,
       CDPRODUTO,
       DTPROGENTR,
       QTSOLIPROD,
       QTSOLIPROD
     FROM
       DELETED
     WHERE
       0 = (SELECT COUNT(*) FROM INSERTED)

     UNION ALL

     SELECT
       'U' IDCOMANDO,
       INSERTED.CDFILSOLI,
       INSERTED.CDFILLAN,
       INSERTED.NRSOLICMP,
       INSERTED.CDPRODUTO,
       INSERTED.DTPROGENTR,
       DELETED.QTSOLIPROD,
       INSERTED.QTSOLIPROD
     FROM
       INSERTED,
       DELETED
     WHERE
       INSERTED.CDFILSOLI   = DELETED.CDFILSOLI   AND
       INSERTED.CDFILLAN    = DELETED.CDFILLAN    AND
       INSERTED.NRSOLICMP   = DELETED.NRSOLICMP   AND
       INSERTED.CDPRODUTO   = DELETED.CDPRODUTO   AND
       INSERTED.DTPROGENTR  = DELETED.DTPROGENTR

     UNION ALL

     SELECT
       'I' IDCOMANDO,
       CDFILSOLI,
       CDFILLAN,
       NRSOLICMP,
       CDPRODUTO,
       DTPROGENTR,
       QTSOLIPROD,
       QTSOLIPROD
     FROM
       INSERTED
     WHERE
       0 = (SELECT COUNT(*) FROM DELETED)

   OPEN C_DADOS;
   FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                @V_CDFILSOLI,
                                @V_CDFILLAN,
                                @V_NRSOLICMP,
                                @V_CDPRODUTO,
                                @V_DTPROGENTR,
                                @V_OLD_QTSOLIPROD,
                                @V_NEW_QTSOLIPROD;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      SELECT @V_IDGRAVLOGSOL = ISNULL(MAX(IDGRAVLOGSOL), 'SSS')
      FROM PARASUPRI
      WHERE (CDFILIAL = (SELECT ISNULL(CDFILCENTCMP, CDFILIAL)
                         FROM FILIAL
                         WHERE (CDFILIAL = @V_CDFILSOLI)));

      SELECT @V_DSRDMUSUMOVS = ISNULL(MAX(DSSERVERRDM), 'VIA BD'),
             @V_DSENDUSUMOVS = ISNULL(MAX(DSREMOTEADDR), 'VIA BD'),
             @V_DSNMUSUMOVS  = ISNULL(MAX(DSREMOTEHOST), 'VIA BD'),
             @V_DSMETUSUMOVS = ISNULL(MAX(DSSERVMETHOD), 'VIA BD')
      FROM SQLWEBTUNNING
      WHERE NRAUDSID = @@SPID AND
            CONVERT(DATETIME, CONVERT(VARCHAR, DTSTARTDATE, 103))  =
                         (SELECT MAX(DTSTARTDATE)
                                  FROM SQLWEBTUNNING S
                                  WHERE S.NRAUDSID = @@SPID);

      IF @V_DSRDMUSUMOVS = 'VIA BD' BEGIN

         IF @V_IDCOMANDO = 'I' /* Inserting */ BEGIN

            IF SUBSTRING(@V_IDGRAVLOGSOL, 1, 1) = 'S' BEGIN

               INSERT INTO MOVOPSOL
               (CDFILSOLMOV, CDFILLANMOV, NRSOLIMOV, CDPRODUTO, DTENTROPER, DTOPERSOL, CDOPERADOR,
                DSJUSTOPER, QTANTOPER, QTDEPOPER, IDOPERAMOVS, DSRDMUSUMOVS, DSENDUSUMOVS,
                DSNMUSUMOVS, DSMETUSUMOVS)
               VALUES
               (@V_CDFILSOLI, @V_CDFILLAN, @V_NRSOLICMP, @V_CDPRODUTO, @V_DTPROGENTR, GETDATE(),
                NULL, 'VIA BD', 0, @V_NEW_QTSOLIPROD, 'I', @V_DSRDMUSUMOVS, @V_DSENDUSUMOVS, @V_DSNMUSUMOVS,
                @V_DSMETUSUMOVS);

            END;

         END;

         IF @V_IDCOMANDO = 'U' /* Updating */ BEGIN

            IF SUBSTRING(@V_IDGRAVLOGSOL, 2, 1) = 'S' BEGIN

               INSERT INTO MOVOPSOL
               (CDFILSOLMOV, CDFILLANMOV, NRSOLIMOV, CDPRODUTO, DTENTROPER, DTOPERSOL, CDOPERADOR,
                DSJUSTOPER, QTANTOPER, QTDEPOPER, IDOPERAMOVS, DSRDMUSUMOVS, DSENDUSUMOVS,
                DSNMUSUMOVS, DSMETUSUMOVS)
               VALUES
               (@V_CDFILSOLI, @V_CDFILLAN, @V_NRSOLICMP, @V_CDPRODUTO, @V_DTPROGENTR, GETDATE(),
                NULL, 'VIA BD', @V_OLD_QTSOLIPROD, @V_NEW_QTSOLIPROD, 'A', @V_DSRDMUSUMOVS, @V_DSENDUSUMOVS, @V_DSNMUSUMOVS,
                @V_DSMETUSUMOVS);

            END;

         END;

         IF @V_IDCOMANDO = 'D' /* Deleting */ BEGIN

            IF SUBSTRING(@V_IDGRAVLOGSOL, 3, 1) = 'S' BEGIN

               INSERT INTO MOVOPSOL
               (CDFILSOLMOV, CDFILLANMOV, NRSOLIMOV, CDPRODUTO, DTENTROPER, DTOPERSOL, CDOPERADOR,
                DSJUSTOPER, QTANTOPER, QTDEPOPER, IDOPERAMOVS, DSRDMUSUMOVS, DSENDUSUMOVS,
                DSNMUSUMOVS, DSMETUSUMOVS)
               VALUES
               (@V_CDFILSOLI, @V_CDFILLAN, @V_NRSOLICMP, @V_CDPRODUTO, @V_DTPROGENTR, GETDATE(),
                NULL, 'VIA BD', @V_OLD_QTSOLIPROD, 0, 'E', @V_DSRDMUSUMOVS, @V_DSENDUSUMOVS, @V_DSNMUSUMOVS,
                @V_DSMETUSUMOVS);

            END;

         END;

      END;
      FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                   @V_CDFILSOLI,
                                   @V_CDFILLAN,
                                   @V_NRSOLICMP,
                                   @V_CDPRODUTO,
                                   @V_DTPROGENTR,
                                   @V_OLD_QTSOLIPROD,
                                   @V_NEW_QTSOLIPROD;

   END;

   CLOSE C_DADOS;
   DEALLOCATE C_DADOS;

END;
GO
